/* FichothequeLib_API - Copyright (c) 2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.utils;

import java.util.AbstractList;
import java.util.Collections;
import java.util.List;
import java.util.RandomAccess;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import net.fichotheque.exportation.balayage.BalayageContentDescription;
import net.fichotheque.exportation.balayage.BalayageDescription;


/**
 *
 * @author Vincent Calame
 */
public final class BalayageUtils {

    public final static List<BalayageContentDescription> EMPTY_BALAYAGECONTENTDESCRIPTIONLIST = Collections.emptyList();
    public final static Pattern XSLTDIR_NAME_PATTERN = Pattern.compile("^[a-zA-Z]([-_a-zA-Z0-9]*)\\.(xml|xsl)$");
    public final static Pattern EXTRACTIONDIR_NAME_PATTERN = Pattern.compile("^[a-zA-Z]([-_a-zA-Z0-9]*)\\.xml$");

    private BalayageUtils() {

    }

    public static boolean isValidContentName(String name, String subdir) {
        if (subdir.isEmpty()) {
            switch (name) {
                case "balayage.xml":
                case "include-catalog.xml":
                    return true;
                default:
                    return false;
            }
        }
        Pattern pattern;
        switch (subdir) {
            case "xslt":
                pattern = XSLTDIR_NAME_PATTERN;
                break;
            case "extraction":
                pattern = EXTRACTIONDIR_NAME_PATTERN;
                break;
            default:
                return false;

        }
        Matcher matcher = pattern.matcher(name);
        return matcher.matches();
    }

    public static String getDefaultContent(String name, String subdir) {
        StringBuilder buf = new StringBuilder();
        buf.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
        int minLength = buf.length();
        if (subdir.isEmpty()) {
            switch (name) {
                case "balayage.xml":
                    buf.append("<balayage>\n\n</balayage>");
                    break;
                case "include-catalog.xml":
                    buf.append("<include-catalog>\n\n</include-catalog>");
            }
        } else if (subdir.equals("extraction")) {
            buf.append("<extraction>\n\n</extraction>");
        } else if ((subdir.equals("xslt")) && (name.endsWith(".xsl"))) {
            buf.append("<xsl:stylesheet xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\" version=\"1.0\">\n\n</xsl:stylesheet>");
        }
        if (buf.length() == minLength) {
            buf.append("<xml>\n</xml>");
        }
        return buf.toString();
    }

    public static List<BalayageDescription> wrap(BalayageDescription[] array) {
        return new BalayageDescriptionList(array);
    }

    public static List<BalayageContentDescription> wrap(BalayageContentDescription[] array) {
        return new BalayageContentDescriptionList(array);
    }

    public static BalayageContentDescription getBalayageContentDescription(BalayageDescription balayageDescription, String contentPath) {
        for (BalayageContentDescription description : balayageDescription.getBalayageContentDescriptionList()) {
            if (description.getPath().equals(contentPath)) {
                return description;
            }
        }
        return null;
    }


    private static class BalayageDescriptionList extends AbstractList<BalayageDescription> implements RandomAccess {

        private final BalayageDescription[] array;

        private BalayageDescriptionList(BalayageDescription[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public BalayageDescription get(int index) {
            return array[index];
        }

    }


    private static class BalayageContentDescriptionList extends AbstractList<BalayageContentDescription> implements RandomAccess {

        private final BalayageContentDescription[] array;

        private BalayageContentDescriptionList(BalayageContentDescription[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public BalayageContentDescription get(int index) {
            return array[index];
        }

    }

}
